@@ -30,7 +30,7 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <glade/glade.h>
 
-#include "global.h"
+#include "xst.h"
 
 #include "transfer.h"
 #include "callbacks.h"
@@ -102,7 +102,7 @@ main (int argc, char *argv[])
 	/* Set accessibility. */
 	set_access_sensitivity ();
 
-	xst_tool_main (tool);
+	xst_tool_main (tool, FALSE);
 
 	return 0;
 }
