@@ -26,7 +26,7 @@
 #endif
 
 #include <gnome.h>
-#include "global.h"
+#include "xst.h"
 #include <gal/e-table/e-table-scrolled.h>
 #include <gal/e-table/e-table-memory.h>
 #include <gal/e-table/e-table-memory-callbacks.h>
@@ -38,6 +38,19 @@
 #include "callbacks.h"
 #include "user-group-xml.h"
 
+#ifdef JUST_FOR_TRANSLATORS
+static char *list [] = {
+	N_("Users"),
+	N_("UID"),
+	N_("Home"),
+	N_("Shell"),
+	N_("Comment"),
+	N_("Group"),
+	N_("GID"),
+	N_("Groups"),
+};
+#endif
+
 extern XstTool *tool;
 
 GtkWidget *user_table;
@@ -47,9 +60,7 @@ GtkWidget *net_user_table;
 
 gint active_table;
 
-/* e-table specifications.
-   WILL BE removed from here SOON!
- */
+/* e-table specifications */
 
 const gchar *user_spec = "\
 <ETableSpecification cursor-mode=\"line\"> \
@@ -196,13 +207,13 @@ user_set_value_at (ETableModel *etm, int col, int row, const void *val, void *da
 		return;
 
 	switch (col) {
-	case COL_USER_LOGIN: user_set_value_login (xd, node, val); break;
-	case COL_USER_UID: user_set_value_uid (xd, node, val); break;
-	case COL_USER_HOME: user_set_value_home (xd, node, val); break;
-	case COL_USER_SHELL: user_set_value_shell (xd, node, val); break;
-	case COL_USER_COMMENT: user_set_value_comment (xd, node, val); break;
-	case COL_USER_GROUP: user_set_value_group (xd, node, val); break;
-	case COL_USER_GID: user_set_value_gid (xd, node, val); break;
+	case COL_USER_LOGIN: user_set_value_login (node, val); break;
+	case COL_USER_UID: user_set_value_uid_string (node, val); break;
+	case COL_USER_HOME: user_set_value_home (node, val); break;
+	case COL_USER_SHELL: user_set_value_shell (node, val); break;
+	case COL_USER_COMMENT: user_set_value_comment (node, val); break;
+	case COL_USER_GROUP: user_set_value_group (node, val); break;
+	case COL_USER_GID: user_set_value_gid_string (node, val); break;
 	default: g_warning ("user_set_value_at: wrong col nr");	break;
 	}
 }
@@ -230,8 +241,11 @@ group_set_value_at (ETableModel *etm, int col, int row, const void *val, void *d
 static gboolean
 is_editable (ETableModel *etm, int col, int row, void *model_data)
 {
-	return (xst_tool_get_access (tool) &&
+/* Temporarily disabled.
+  return (xst_tool_get_access (tool) &&
 		   (xst_dialog_get_complexity (tool->main_dialog) == XST_DIALOG_ADVANCED));
+*/
+	return FALSE;
 }
 
 static void *
@@ -563,7 +577,7 @@ create_user_table (void)
 	table = e_table_scrolled_get_table (E_TABLE_SCROLLED (user_table));
 	table_connect_signals (table);
 	gtk_signal_connect (GTK_OBJECT (table), "cursor_change", cursor_change, NULL);
-	gtk_signal_connect (GTK_OBJECT (table), "double_click", on_settings_clicked, NULL);
+	gtk_signal_connect (GTK_OBJECT (table), "double_click", on_user_settings_clicked, NULL);
 
 	container = xst_dialog_get_widget (tool->main_dialog, "users_holder");
 	gtk_container_add (GTK_CONTAINER (container), user_table);
@@ -823,7 +837,7 @@ tables_update_content (void)
 }
 
 void
-tables_set_state (gboolean state)
+tables_update_complexity (XstDialogComplexity complexity)
 {
 	ETable *u_table, *g_table;
 	gchar *user_state, *group_state;
@@ -831,12 +845,18 @@ tables_set_state (gboolean state)
 	u_table = e_table_scrolled_get_table (E_TABLE_SCROLLED (user_table));
 	g_table = e_table_scrolled_get_table (E_TABLE_SCROLLED (group_table));
 
-	if (state) {
-		user_state =  xst_conf_get_string (tool, "user_state_adv");
-		group_state = xst_conf_get_string (tool, "group_state_adv");
-	} else {
+	switch (complexity) {
+	case XST_DIALOG_BASIC:
 		user_state =  xst_conf_get_string (tool, "user_state_basic");
 		group_state = xst_conf_get_string (tool, "group_state_basic");
+		break;
+	case XST_DIALOG_ADVANCED:
+		user_state =  xst_conf_get_string (tool, "user_state_adv");
+		group_state = xst_conf_get_string (tool, "group_state_adv");
+		break;
+	default:
+		g_warning ("update_notebook_complexity: Unsupported complexity.");
+		return;
 	}
 
 	e_table_set_state (u_table, user_state);
